export declare const typeDefs = "\n  scalar DateTime\n  scalar JSON\n  scalar JSONObject\n\n  type Query\n    @sqlmancer(\n      dialect: POSTGRES\n      transformFieldNames: SNAKE_CASE\n      customScalars: { JSON: [\"JSON\", \"JSONObject\"], Date: [\"DateTime\"] }\n    ) {\n    actors: [Actor!]! @many\n    actor(id: ID!): Actor\n    actorsPaginated: Actor @paginate @many(model: \"Actor\")\n    films: [Film!]! @limit @offset @where @orderBy\n    film(id: ID!): Film\n    filmsPaginated: Film @paginate @many(model: \"Film\")\n    customers: [Customer!]! @many\n    customer(id: ID!): Customer\n    addresses: [Address!]! @many\n    address(id: ID!): Address\n    movies: [Movie!]! @many\n    people: [Person!]! @many\n  }\n\n  type Mutation {\n    createCustomer: Customer @input(action: CREATE)\n    createCustomers: [Customer!]! @input(action: CREATE, list: true)\n    deleteCustomer(id: ID): Boolean!\n    deleteCustomers: Boolean! @where(model: \"Customer\")\n    updateCustomer(id: ID): Customer @input(action: UPDATE)\n    updateCustomers: [Customer!]! @where @input(action: UPDATE)\n  }\n\n  type Actor @model(table: \"actor\", pk: \"actor_id\") {\n    id: ID! @col(name: \"actor_id\") @hasDefault\n    firstName: String!\n    lastName: String!\n    lastUpdate: DateTime! @hasDefault\n    films: [Film!]!\n      @relate(on: [{ from: \"actor_id\", to: \"actor_id\" }, { from: \"film_id\", to: \"film_id\" }], through: \"film_actor\")\n      @many\n    filmsPaginated: Film\n      @relate(\n        on: [{ from: \"actor_id\", to: \"actor_id\" }, { from: \"film_id\", to: \"film_id\" }]\n        through: \"film_actor\"\n        pagination: OFFSET\n      )\n      @paginate\n      @many(model: \"Film\")\n  }\n\n  type Film @model(table: \"film\", pk: \"film_id\") {\n    id: ID! @col(name: \"film_id\") @hasDefault\n    title: String!\n    description: String!\n    releaseYear: Int!\n    length: Int!\n    rating: FilmRating!\n    rentalRate: Float!\n    rentalDuration: Int!\n    replacementCost: Float!\n    specialFeatures: [String!]!\n    extraData: JSON!\n    lastUpdate: DateTime! @hasDefault\n    actors: [Actor!]!\n      @relate(on: [{ from: \"film_id\", to: \"film_id\" }, { from: \"actor_id\", to: \"actor_id\" }], through: \"film_actor\")\n      @many\n    categories: [Category!]!\n      @relate(\n        on: [{ from: \"film_id\", to: \"film_id\" }, { from: \"category_id\", to: \"category_id\" }]\n        through: \"film_category\"\n      )\n      @many\n    actorsPaginated: Actor\n      @relate(\n        on: [{ from: \"film_id\", to: \"film_id\" }, { from: \"actor_id\", to: \"actor_id\" }]\n        through: \"film_actor\"\n        pagination: OFFSET\n      )\n      @paginate\n      @many(model: \"Actor\")\n    language: Language! @relate(on: { from: \"language_id\", to: \"language_id\" })\n    originalLanguage: Language @relate(on: { from: \"original_language_id\", to: \"language_id\" })\n    sequel: Film @relate(on: { from: \"sequel_id\", to: \"film_id\" })\n  }\n\n  type Language @model(table: \"language\", pk: \"language_id\") {\n    id: ID! @col(name: \"language_id\") @hasDefault\n    name: String!\n    lastUpdate: DateTime! @hasDefault\n    films: [Film!]! @relate(on: { from: \"language_id\", to: \"language_id\" }) @many\n    filmsPaginated: Film\n      @relate(on: { from: \"language_id\", to: \"language_id\" }, pagination: OFFSET)\n      @paginate\n      @many(model: \"Film\")\n  }\n\n  type Customer @model(table: \"customer\", pk: \"customer_id\") {\n    id: ID! @col(name: \"customer_id\") @hasDefault\n    firstName: String!\n    lastName: String!\n    email: String\n    lastUpdate: DateTime! @hasDefault\n  }\n\n  type CreateCustomerPayload {\n    customer: Film\n    message: String\n  }\n\n  type Category @model(table: \"category\", pk: \"category_id\", readOnly: true) {\n    id: ID! @col(name: \"category_id\") @hasDefault\n    name: String!\n    lastUpdate: DateTime! @hasDefault\n    films: [Film!]!\n      @relate(\n        on: [{ from: \"category_id\", to: \"category_id\" }, { from: \"film_id\", to: \"film_id\" }]\n        through: \"film_category\"\n      )\n      @many\n  }\n\n  type Address\n    @model(\n      pk: \"id\"\n      cte: \"\"\"\n      SELECT\n        address.address_id AS id,\n        address.address AS address_line,\n        address.address2 AS address_line_2,\n        address.postal_code AS postal_code,\n        city.city AS city,\n        country.country AS country,\n        address.last_update AS last_update\n      FROM address\n      INNER JOIN city ON address.city_id = city.city_id\n      INNER JOIN country ON city.country_id = country.country_id\n      \"\"\"\n    ) {\n    id: ID!\n    addressLine: String!\n    addressLine2: String\n    postalCode: String\n    city: String!\n    country: String!\n    lastUpdate: DateTime!\n  }\n\n  interface Movie @model(table: \"film\", pk: \"film_id\", include: [\"length\"]) {\n    id: ID!\n    title: String!\n    description: String!\n    releaseYear: Int!\n    length: Int!\n    rating: FilmRating!\n    rentalRate: Float!\n    rentalDuration: Int!\n    replacementCost: Float!\n    extraData: JSON!\n    lastUpdate: DateTime!\n  }\n\n  type ShortMovie implements Movie {\n    id: ID! @col(name: \"film_id\") @hasDefault\n    title: String!\n    description: String!\n    releaseYear: Int!\n    length: Int!\n    rating: FilmRating!\n    rentalRate: Float!\n    rentalDuration: Int!\n    replacementCost: Float!\n    extraData: JSON!\n    lastUpdate: DateTime! @hasDefault\n  }\n\n  type LongMovie implements Movie {\n    id: ID! @col(name: \"film_id\") @hasDefault\n    title: String!\n    description: String!\n    releaseYear: Int!\n    length: Int!\n    rating: FilmRating!\n    rentalRate: Float!\n    rentalDuration: Int!\n    replacementCost: Float!\n    extraData: JSON!\n    lastUpdate: DateTime! @hasDefault\n  }\n\n  union Person\n    @model(\n      pk: \"customer_id\"\n      cte: \"\"\"\n      SELECT\n      'customer_' || customer_id as customer_id,\n        first_name,\n        last_name,\n        email,\n        last_update,\n        'Customer' as __typename\n      FROM customer\n      UNION\n      SELECT\n        'actor' || actor_id as customer_id,\n        first_name,\n        last_name,\n        NULL as email,\n        last_update,\n        'Actor' as __typename\n      FROM actor\n      \"\"\"\n      include: [\"__typename\"]\n    ) =\n      Actor\n    | Customer\n\n  enum FilmRating {\n    G\n    PG\n    PG13 @value(is: \"PG-13\")\n    R\n    NC17 @value(is: \"NC-17\")\n  }\n";
export declare const schemaWithoutDirectives: import("graphql").GraphQLSchema;
export declare const schemaWithDirectives: import("graphql").GraphQLSchema;
